#
# spec file for package seahorse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           seahorse
Version:        43.0+22
Release:        1.2
Summary:        GNOME interface for gnupg
License:        GFDL-1.1-only AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://wiki.gnome.org/Apps/Seahorse
Source0:        %{name}-%{version}.tar.zst
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gpg2 >= 2.2.0
BuildRequires:  libxslt-tools
BuildRequires:  meson >= 0.51
BuildRequires:  openldap2-devel
BuildRequires:  openssh
BuildRequires:  pkcs11-helper-devel
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(avahi-glib) >= 0.6
BuildRequires:  pkgconfig(gcr-3) >= 3.18
BuildRequires:  pkgconfig(gcr-ui-3) >= 3.18
BuildRequires:  pkgconfig(gio-2.0) >= 2.66
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.66
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.66
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66
BuildRequires:  pkgconfig(gpgme) >= 1.14.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libhandy-1) >= 1.5.0
BuildRequires:  pkgconfig(libsecret-1) >= 0.16
BuildRequires:  pkgconfig(libsoup-3.0) >= 2.33.92
BuildRequires:  pkgconfig(pwquality)
Obsoletes:      %{name}-devel < %{version}

%description
Seahorse is a GNOME interface for gnupg. It uses gpgme as the backend.

%package -n gnome-shell-search-provider-seahorse
Summary:        GNOME interface for gnupg -- Search Provider for GNOME Shell
Group:          Productivity/Security
Supplements:    (%{name} and gnome-shell)
BuildArch:      noarch

%description -n gnome-shell-search-provider-seahorse
Seahorse is a GNOME interface for gnupg. It uses gpgme as the backend.

This package contains a search provider to enable GNOME Shell to get
search results from seahorse.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dpgp-support=true \
	-Dcheck-compatible-gpg=true \
	-Dpkcs11-support=true \
	-Dkeyservers-support=true \
	-Dhkp-support=true \
	-Dldap-support=true \
	-Dkey-sharing=true \
	-Dmanpage=true \
	%{nil}
%meson_build

%check
%meson_test

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING COPYING-DOCS COPYING.LIB
%doc NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/seahorse
%{_libexecdir}/seahorse/
%{_datadir}/applications/org.gnome.seahorse.Application.desktop
%{_datadir}/dbus-1/services/org.gnome.seahorse.Application.service
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.*xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/org.gnome.seahorse.Application.appdata.xml
%{_datadir}/seahorse/
%{_mandir}/man1/seahorse.1%{?ext_man}

%files -n gnome-shell-search-provider-seahorse
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/seahorse-search-provider.ini

%files lang -f %{name}.lang

%changelog
* Wed Feb 28 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.0+22:
  + Avoid C99 incompatibility around
    seahorse_pkcs11_backend_initialize.
  + Allow building with GnuPG-2.4.x.
- Drop 9260c747.patch: fixed upstream.
* Fri Jan  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 9260c747.patch: Allow building with GnuPG-2.4.x.
* Mon Dec 12 2022 Callum Farmer <gmbr3@opensuse.org>
- The shell provider dbus service file must be in the main package
  due to being referenced in the .desktop file
* Fri Oct 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + When showing an empty page, there's now a button to add a new
    item directly.
  + Fixed some warnings related to .authorized_keys or .other_keys
    not existing on the system.
  + Keysharing over DNS-SD is now disabled by default.
  + Port to libsoup3.
  + Updated translations.
- Drop ab2f253c.patch: Fixed upstream.
- Add desktop-file-utils BuildRequires: New dependency.
- Add appstream-glib BuildRequires: Optional BuildRequires for
  validation of appdata during meson_test.
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add ab2f253c.patch: Port to soup3. Following this, replace
  pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0) BuildRequires.
- Build sub-package gnome-shell-search-provider-seahorse as noarch.
* Mon May 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.0:
  + pgp: Fix GPG version check.
  + desktop: Add pgp,gpg to the description.
  + search-provider: Don't escape result description as markup.
  + gkr: Network label fixes.
  + ssh: Fix CPU Usage Spike When Calling ssh-keygen.
  + desktop: Add supported mime types to .desktop file>
  + desktop: Mark application as adaptive.
  + metainfo: Align app name with .desktop name.
  + ui: Opt-in to color scheme user preference>
  + Updated translations.
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + appdata: State hardware support.
  + Updated translations.
- Update Supplements syntax in sub-package to current standard.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.beta:
  + pgp:
  - Redesign of the PGP key properties dialog
  - Also monitor .kbx in gpghomedir, making sure we get notified
    of new keys
  - Start adding (basic) unit tests
  - Make pgp key id equality accept more values
  - Make HKP keyid check more robust
  - Fix expiration date for certain keys
  - Allow building with GnuPG-2.3.x
  - Fix segfault when built with LDAP disabled
  + ui:
  - Follow GNOME HIG more closely [!178]
  - Datepicker now only pops down on double click
  + gkr:
  - Fix warnings for items with NULL labels
  - Don't show "Details" if no attributes are shown
  + appdata: Updated screenshot
  + Update README.md
  + Updated translations.
* Tue Apr 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Fix paint issue when unlocking empty login keyring
    (boo#1179003).
  + pgp:
  - Properly fix keyserver registration.
  - Add unit tests for PGP keyserver code.
  * build: Unbreak build using vala 0.48.x.
  * ci: Add minimal style checks to the CI.
  * Several code cleanups.
  * Updated translations.
- Drop 153.patch: fixed upstream.
* Tue Feb 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Fix import dialog.
  + pgp:
  - Add support for HKPS servers.
  - Allow empty passphrase on key creation.
  - Fix expiry container disabled.
  + gkr: Add icon for network passwords.
  + ui: use libhandy list styling.
  + deps:
  - Bump to libhandy 1.1 and remove submodule.
  - Bump minimal supported version of gcr.
  - Bump minimal supported versions of gpg/gpgme.
  + Updated translations.
* Mon Feb 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 153.patch: key-manager: Make sure to update after unlocking
  (boo#1179003).
* Mon Feb 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + ui: Bind to list item to listen to changes.
  + Updated translations.
* Sun Nov  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.0.1:
  + Fix detection of libhandy-1.
- Drop seahorse-fix-libhandy.patch, fixed upstream.
* Sat Nov  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.0:
  + Bump to libhandy1.
  + Updated translations.
- Replace pkgconfig(libhandy-0.0) for pkgconfig(libhandy-1)
  BuildRequires following upstreams changes.
- Add seahorse-fix-libhandy.patch, fix detection of new libhandy.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.2:
  + help: Several updates to the help pages.
  + gkr: Allow copying password secret with right click.
  + pgp: Don't show 'Indicate trust' before importing.
  + ssh: Fix "allow remote access".
- Changes from version 3.37.1:
  + Better keyboard navigation.
  + pgp: Set input-purpose on relevant entries.
  + Don't use wrongful mnemonic for Import.
  + Several fixes to the help pages.
  + Updated translations.
* Sat Jun 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Revert accidental string freeze break.
* Sat Jun 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Updated help pages.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36:
  + Add hyperlink for COPYING in README.
  + meson: Validate appdata and desktop files.
  + flatpak: Remove dconf workaround.
  + flatpak: Remove libsoup.
  + gkr: Try to guess the username.
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + ui:
  - Add F10 shortcut for 'open menu'.
  - Remove ctrl+f1 shortcut.
  + pgp:
  - Allow exporting both public & secret key.
  - Use gpgme_op_create_subkey() over gpgme_op_edit().
  - Port several dialogs to GtkTemplate.
  - Small UI changes to KeyProperties.
  + gkr:
  - Try to display a username if available.
  - Strip verbose 'Network secret for' prefix.
  - Use "network-wired" icon for NM secret.
  + common: Remove SeahorseObjectWidget.
  + css: Fix a missing 'px' unit.
  + meson: Use files() for source.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + a11y: Make sure import buttons have a mnemonic.
  + ui:
  - Add keyboard shortcuts window.
  - Take initials steps to provide an adaptive UI.
  - Remove "Show combined" option.
  - sidebar: Group by Passwords, Keys, Certificates.
  - sidebar: Don't show "System Trust" if empty.
  + ssh: Show the public key and add button to copy it.
  + pgp: Don't use short key IDs.
  + build: glgo#GNOME/seahorse!103, glgo#GNOME/seahorse!104,
    glgo#GNOME/seahorse!110, glgo#GNOME/seahorse!113.
- Changes from version 3.35.1:
  + Replace GtkFileChooserDialog with GtkFileChooserNative.
  + Add development profile.
  + icon: Create a nightly app icon.
  + pgp:
  - Update documentation for exporting public keys
  - Fix segfault when deleting subkeys (glgo#GNOME/seahorse#250).
  - Fix deadlock with trust-model tofu or tofu-pgp
    (glgo#GNOME/seahorse#2).
  + Updated translations.
- Replace libgpgme-devel BuildRequires with pkgconfig(gpgme).
- Add pkgcofig(libhandy-0.0) BuildRequires: new dependency.
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix crash when deleting a subkey.
  + Fix a deadlock when using tofu trust model.
  + Updated translations.
* Tue Oct  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34:
  + gkr: Fix use-after-free in password interaction.
  + Add OARS Metadata tags.
  + Cleanup flatpak manifest.
  + gkr: Fix a build failure due to a GKR GIR breakage.
  + Depend on meson version >= 0.49.
  + Fix a crash for some Epiphany passwords.
  + Add mnemonics.
  + ssh: Use Posix.Signal.TERM to unbreak building with valac
    <= 0.40.
  + Enable type-to-search.
  + pgp: Fix a segfault when syncing GPG keys to an HKP server.
  + gkr: Update user documentation for keyrings.
  + Generate manpage from XML file.
  + Implement GApplication.open() so we can import files from the
    command line.
  + pgp: Fix build related to GPG(ME) versions.
- Add docbook-xsl-stylesheets and libxslt-tools BuildRequires and
  pass manpage=true to meson: Build manpages.
* Thu May 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + appdata: Update the contact details and add OARS metadata.
  + gkr: Fix a crash for some Epiphany passwords.
* Sun Apr 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Enable type-to-search.
  + Fix errors when building with valac < 0.40.
  + pgp: Fix crash when syncing GPG keys to HKP server.
  + Update documentation for import/exporting keys / creating
    keyrings.
  + Fix build with -Dcheck-compatible-gpg=false.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32:
  + Fix regression: no more context menu in sidebar.
  + gkr: Fix crash when renaming keyring.
  + pgp: Don't use a custom person icon.
  + gpgme: Don't use gpgme_op_edit for exporting or making a UID
    primary.
  + Port more GSimpleAsyncResult to GTask.
  + flatpak: fix network permissions.
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Remove deprecated g_type_class_add_private.
  + flatpak: Add dependencies for key sharing/importing.
  + gkr:
  - Recognize GNOME Web (Epiphany) passwords and adjust UI.
  - Recognize user-specific Wi-Fi passwords.
  - Use application icon for password of known installed app.
  - Fix Chrome password recognition.
  - Add password strength indicator when adding a new password.
  + pgp:
  - Always use gpgme_op_export_start when exporting.
  - Cleanup the UI of the key properties dialog.
  + Add an empty state indicator.
  + Add <ctrl>f as an accelerator for the search bar.
  + Start migration of GSimpleAsyncResult to GTask.
  + Migrate some widget from SeahorseWidget to GtkTemplate.
- Add pkgconfig(pwquality) BuildRequires: New dependency.
* Wed Jan  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Port most uses of Gtk.Action to GLib.Action.
  + New app icon.
  + Use a header bar.
  + Updated password properties dialog.
  + Updated SSH key properties dialog.
  + Update view when new item is added.
  + UI tweaks to the KeyManager list.
  + pgp: small cleanups.
  + Vala fixes.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 3.30.1.1:
  + Fix Vala build issue due to GLib.List type mismatch.
- Changes from version 3.30.1:
  + gkr: Passwords are filtered out when "personal".
  + ssh: Fix key creation with quotes in the name.
  + pgp: A progress bar is again shown when creating a PGP key.
  + Resolved a crash when pasting e.g. a file into the window.
  + Updated translations.
* Sun Sep 23 2018 antoine.belvire@opensuse.org
- Update to version 3.30:
  + Fix no window when launched from .desktop
    (glgo#GNOME/seahorse#192, glgo#GNOME/seahorse#16).
  + Show active window if available on launch
    (glgo#GNOME/seahorse#18).
  + Add debug logging for filtering.
  + Make yelp documentation optional (glgo#GNOME/seahorse#17).
  + Drop Continuous' configure script (glgo#GNOME/seahorse#12).
  + Fix build on debian (glgo#GNOME/seahorse#190).
  + Updated translations.
- Drop seahorse-fix-ldap-undefined-references.patch: Fixed
  upstream.
- No longer recommend lang package as it already supplements main
  package (same effect, it's redundant).
* Fri Aug 31 2018 luc14n0@linuxmail.org
- Add seahorse-fix-ldap-undefined-references.patch provided by
  upstream (glgo#GNOME/seahorse!15) and re-enable ldap support.
* Fri Aug 31 2018 luc14n0@linuxmail.org
- Update to version 3.29.92:
  + gkr: fix segfault when trying to change default keyring
    password (glgo#GNOME/seahorse#182).
  + Fix - Cannot delete multi-selected SSH keys
    (glgo#GNOME/seahorse#105, glgo#GNOME/seahorse!9).
  + pgp: Seahorse again correctly filters keys for signing
    (glgo#GNOME/seahorse!11).
  + pgp: Search keys dialog now properly lists key servers again
    (glgo#GNOME/seahorse!10).
  + gkr: Fix lock/unlock button tooltip text in keyring properties
    (glgo#GNOME/seahorse!5).
  + Updated translations.
- Enable tests run to increase QA of package.
* Wed Aug 15 2018 luc14n0@linuxmail.org
- Update to 3.29.91:
  + pgp: remove non-working Help button (glgo#GNOME/seahorse#164).
  + gkr: Fix lock/unlock button in keyring properties.
  + ssh: Fix upload button.
  + Use header bars more consistently.
  + Updated translations.
- Changes from version 3.29.90:
  + pgp: add hint when 'Full name' is not long enough (bgo#395805).
  + gkr: ask for confirmation when saving changes (bgo#712348).
  + gkr: Don't update key description if it doesn't change
    (bgo#777802).
  + ssh: modify the key length options based on the type of
    encryption.
  + ssh: add basic support for ECDSA and ED25519 keys (bgo#754028).
  + Several small documentation fixes.
  + Updated translations.
- Add:
  + meson BuildRequires and replace configure/make/make_install
    macros/command with meson/meson_build_meson_install,
    respectively; and pass pgp-support, check-compatible-gpg,
    pkcs11-support, keyservers-support, hkp-support, ldap-support,
    key-sharing options to meson as true (upstream defaults),
    following upstream port to Meson build system.
  + glib-2.0, gobject-2.0, gio-unix-2.0 and gmodule-2.0 pkgconfig
    modules as BuilRequires to avoid implicit dependencies.
  + libpkcs11-helper-devel BuildRequires: this is needed for
    PKCS#11 support.
- Drop:
  + Fixed upstream patches: seahorse-new-gnupg.patch and
    seahorse-gpg-ignore-key-considered.patch (bgo#778607).
  + autoconf, and its autoreconf call, and automake BuildRequires:
    they are no longer needed, they were added only because of the
    previous dropped patches.
  + intltool BuildRequires: this is no longer needed since upstream
    migrated to Gettext.
  + update-desktop-files BuildRequires and suse_update_desktop_file
    macro: they are no longer needed.
  + glib2_gsettings_schema_requires macro: this is no longer needed
    since RPM file triggers (version >= 4.13).
  + Pristine Obsoletes targeted at openSUSE release <= 12.1.
- Switch:
  + libsecret-unstable and gck-1 pkgconfig modules to libsecret-1
    and gck-ui-3, respectively, to conform with meson dependency
    checks. Note that libsecret-1 and gck-ui-3 were already being
    used since they are provided by the same package as the
    switched modules.
  + gpgme-devel BuildRequire to libgpgme-devel: this is the right
    openSUSE package name.
- Point fdupes to the datadir (/usr/share/) rather than the whole
  buildroot, which is a practice that must be avoided when hard
  linking.
* Tue Mar 27 2018 dimstar@opensuse.org
- Add explicit call to autoreconf: some of the patches touch the
  build system.
- Drop -lib2_gsettings_schema_post[un], desktop_database_post[un]
  and icon_theme_cache_post[un] usage from post/postun scripts: the
  functionality covered by file triggers.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Jan 15 2018 mgorse@suse.com
- Add seahorse-gpg-ignore-key-considered.patch: ignore new
  key_considered line (bgo#779607).
- Add seahorse-new-gnupg.patch: Mark gnupg 2.2.x as supported, so
  that our builds enable gpg again (bsc#1075928).
- Drop seahorse-allow-deprecated.patch: seahorse builds without it.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Fri Mar 25 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Update AppData spec file.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Build fixes (bgo#758472).
  + Updated translations.
* Tue Sep 29 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Use the application name in the software center.
  + Updated translations.
* Tue Aug  4 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Avoid binding seahorse to the build-time version of GnuPG
    (bgo#750468).
  + Fix seahorse shell search provider (bgo#704619).
  + Use GResource to load UI resources (bgo#752516).
  + Build fixes: bgo#744503, bgo#752990.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Provide a symbolic variant of the app icon (bgo#747244).
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Don't use deprecated GtkArrow (bgo#744195).
  + Updated translations.
* Sat Feb 28 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Refactoring and revamping help files.
  + Work around for breakage with gnupg2.
  + Fix invalid UI files (bgo#740138).
  + Updated translations.
* Sat Feb 28 2015 zaitor@opensuse.org
- Update to version 3.14.1:
  + Don't hide GtkBuilder errors (bgo#740138).
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix crash in search provider (bgo#733957).
  + Display 'Certify' and 'Authenticate' names for GPG key flags
    (bgo#733920).
  + Prettify fingerprint downloaded from key server (bgo#719872).
  + When searching for keys request full fingerprint (bgo#719872).
  + Show whether subkeys can be used for signing/encryption
    (bgo#730044).
  + Remove incorrect tooltip from 'New Keyring' dialog
    (bgo#733399).
  + Updated translations
  + Build fixes (bgo#732396).
* Tue Jul 15 2014 dimstar@opensuse.org
- Add seahorse-allow-deprecated.patch: Allow the usage of
  deprecated GTK+ symbols.
- No longer pass --disable-scrollkeeper to configure: this hasn't
  been supported since version 3.5.92 when the switched from
  gnome-devel-docs to Mallard happened.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Allow scrolled windows to grow when properties window resized
    (bgo#727850).
  + Don't open keyserver results behind main seahorse window
    (bgo#727926).
  + Prettify fingerprints in a smarter way (bgo#719872).
  + Documentation fixes.
  + Build fixes (bgo#725728).
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + New help pages from the malard documentation project.
  + Build fixes.
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Fri Mar  7 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Fix segfault in the search provider code (bgo#724659).
  + Port some more seahorse code to vala code.
  + Non-recursive Makefile.
  + Updated FSF's address.
  + Add AppData file.
  + Build fixes. No libtool (bgo#722023, bgo#712538, bgo#712538).
  + Updated translations.
* Wed Jan  8 2014 dimstar@opensuse.org
- Update to version 3.10.2:
  + Fix pgp/ssh key export (bgo#707014).
  + Fix SSH key generation (bgo#715051).
  + Update homepage URL.
  + Build fixes (bgo#712538).
  + Updated translations.
- Drop seahorse-ssh-keypair.patch: fixed upstream.
* Sat Nov 23 2013 dimstar@opensuse.org
- Add seahorse-ssh-keypair.patch: Fix SSH key generation
  (bnc#851050, bgo#715053).
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Fix generate-select dialog for GTK+ changes (bgo#703825).
  + Try to make as many password dialogs transient as possible.
  + Build fixes (bgo#708827, bgo#710069).
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Translation fixes (bgo#707420).
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Documentation fixes (bgo#707135).
  + Updated translations.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Show the sidebar by default (bgo#705592).
  + ssh: Bump the minimum key size to 768 bits (bgo#705561).
  + Add "DesktopSettings;X-XFCE-SettingsDialog;" to .desktop
    categories (bgo#704981).
  + pgp: Put the 'Comment' field in the advanced section of PGP key
    gen (bgo#703766).
  + Only permit import from clipboard when data is available
    (bgo#703394).
  + soup: use the SoupProxyResolverDefault feature (bgo#682495).
  + pgp: Fix uninitialized memory access.
  + Port some of seahorse to vala code.
  + Build fixes (bgo#702602, bgo#699147).
  + Translation fixes (bgo#699116).
  + Updated translations.
- Drop seahorse-remove-bad-help-buttons.patch: fixed upstream.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Add a shell search provider for passwords and keys
    (bgo#694606).
  + Start using vala for internal interfaces.
  + Build fixes.
  + Updated translations.
- Add vala BuildRequires: needed, as internals are now built in
  vala.
- Create new subpackage gnome-shell-search-provider-seahorse.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Don't show preferences when no preferences are available
    (bgo#694678).
  + Don't conflict with seahorse-daemon DBus name (bgo#694053).
  + Fix command line options parsing (bgo#686980).
  + Build fixes.
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Added keywords to .desktop file.
  + Build fixes.
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Build fixes.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Correct capitalization of ElGamal.
  + Build fixes.
* Wed Feb 20 2013 mike.catanzaro@gmail.com
- Add seahorse-remove-bad-help-buttons.patch (bnc#804181)
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.3:
  + Display item labels even if they don't match formatters.
  + Fix crashers.
  + Updated translations.
* Tue Oct 23 2012 vuntz@opensuse.org
- Update to version 3.6.2:
  + Fix problem where keyring items overwrite one another.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Strip DBus errors before displaying them.
  + Fix regression for changing a keyring master password.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Port to new documentation infrastructure
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequieres with yelp-tools:
  following upstreams port to new documentation infrastructure.
* Thu Sep  6 2012 dimstar@opensuse.org
- No longer mangle Generic name and Name of the programs entry in
  the menus / activities screen:
  + Remove  -G "Passwords and Keys" -N "Seahorse" from the
    suse_update_desktop_file call (bnc#779068).
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + No keyring UI bits if failed to connect to Secret Service
  + When Ctrl-F pressed in the main window, focus the filter box
  + Add suggestion to generate entropy while generating a key
  + Use libsecret instead of libgnome-keyring
  + Use GcrSecureEntryBuffer and remove duplicate code.
  + Align keyids with name/signatures in key properties.
  + Unavailable entries were displayed incorrectly for signatures
  + Fix icon sizes
  + Remove unused code
  + Migrate to GtkApplication
  + Other bug fixes
  + Build fixes
  + Updated translations.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams switch.
- Drop xz BuildRequires as it now comes for free in the build
  system.
- Drop seahorse-gpgme-keyring.patch: fixed upstream.
* Fri May 18 2012 dimstar@opensuse.org
- Add seahorse-gpgme-keyring.patch: Fix typo in finalizing GPGME
  keyring.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix crash during failed HKP exports
  + Fix memory errors when searching for keys
  + Build fixes
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Fix warning cancelling the signing dialog.
  + If multiple keys with same label in signer list, add hex keyid.
  + Build fixes.
  + Updated translations.
* Thu Mar 15 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Fix regression of configure ssh keys
  + Fix line on top of the sidebar
  + Updated translations.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Maximum and minimum sidebar pane position
  + Fix icons for filter entry
  + Fix uninitialized memory usage
  + Clearer wording for various keyrings
  + Build fixes
  + Updated translations.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Remove limitation of max keyring item description characters
  + Build fixes
  + Updated translations.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Support for PKCS#11 key generation
  + Support for creating certificate requests
  + Certificate actions happen from certificate window.
  + Reimplement export functionality
  + Refactor deletion, unlocking, refreshing, and showing
    properties
  + Add way to lookup places, and refresh appropriate place after
    import
  + Fixes for glib 2.31.x deprecations
  + Fix bugs, build issues, translations
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Refactoring of how actions work
  + Add ability to lock and unlock places from the sidebar
  + Implement login to smart cards and PKCS#11 tokens
  + Remove experimental check selection on sidebar
  + Listing of private keys on smart cards and PKCS#11 tokens
  + Showing matching keys and certificates together, in listing and
    properties
  + Build fixes
  + Don't crash if gpg or gpg2 don't run correctly.
  + Fix problems editing PGP key servers
  + Don't load key signatures unless showing key properties
  + Updated translations.
- Drop seahorse-fix-crash-on-keyserver-add.patch: fixed upstream.
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 3.3.1.1:
  + Fix build issues when pgp, ssh, or pkcs11 backends are disabled
  + Updated translations
- Changes from version 3.3.1:
  + Major refactoring of look and behavior of seahorse
  + Passwords, keys and certs are displayed together in the main
    window
  + Places sidebar, which can be shown, to access where various
    objects come from
  + Asynchronously initialize PKCS#11 modules
  + Use the new importer infrastructure in libgcr
  + Blacklist certain PKCS#11 tokens from showing up in seahorse
  + Code cleanup and refactoring
  + Build, translation fixes
  + Updated translations.
* Mon Oct 17 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Oct 17 2011 vuntz@opensuse.org
- Add seahorse-plugins Obsoletes to help smooth upgrades, since we
  dropped the package.
* Thu Oct 13 2011 vuntz@opensuse.org
- Add seahorse-fix-crash-on-keyserver-add.patch: fix crash when
  adding a keyserver. Fix bnc#723908.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix DNS-SD key sharing crasher and make compatible with
    seahorse-sharing
  + Updated translations.
* Sun Sep 18 2011 zaitor@opensuse.org
- Update Url tag to current project homepage.
* Sun Sep 18 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix the SSH password prompting and uploading of keys
  + Fix behavior of password prompts when enter is pressed
  + Fix GtkComboText GTK+3 problems
  + Fix crasher when closing
  + Build and documentation fixes
  + Updated translations
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Fix up for recent GTK+3 changes.
  + Code cleanup, removing unused code.
  + Remove old GTK+2 code that was missed earlier.
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Change application name to shorter 'Passwords and Keys'
  + Fix drop downs in key generation dialogs
  + Don't distribute internal libseahorse documentation
  + Match changes in libgck and libgcr
  + Remove old operation code, and replace with newer gio style
    async
  + Remove unused code and cleanup
  + Port to GSettings (instead of using GConf)
  + Add Glib style debug messages, activated with SEAHORSE_DEBUG=all
  + Translation and build fixes
- Remove pkgconfig(gconf-2.0) BuildRequires,
  - -disable-schemas-install from configure call and usage of gconf
  macros; move to %%glib2_gsettings_schema_* macros instead. This is
  following the port to GSettings.
- Update GenericName we set for seahorse.desktop to 'Passwords and
  Keys', following upstream.
- Remove hacky removal of libseahorse gtk-doc in %%install now that
  it is gone.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Create new keyring items in the right keyring.
  + Remove dependency on GTK+ 2.x.
  + Split out libcryptui into its own module.
- Remove gobject-introspection-devel and libnotify-devel
  BuildRequires: the dependencies are now gone.
- Remove libassuan-devel, libgpg-error-devel, libxml2-devel
  BuildRequires: they weren't needed.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gconf2-devel, libavahi-glib-devel, libgck-devel,
    libgcr-devel, libgnome-keyring-devel, libsoup-devel.
  + New ones: avahi-client, avahi-glib, gck-1, gconf-2.0, gcr-3,
    gio-2.0, gnome-keyring-1, gtk+-3.0, libsoup-2.4.
- Manually remove %%{_datadir}/gtk-doc/html/libseahorse/ as there is
  no libseahorse public library.
- Drop devel subpackage since there is no file left for it. Add an
  Obsoletes for it to the main package for smooth upgrades.
- Remove --with-gtk=3.0 from configure, as GTK+ 2.x support was
  removed.
- Remove /sbin/ldconfig call from %%post/%%postun as there's no
  library anymore.
* Fri May 27 2011 vuntz@opensuse.org
- Drop seahorse-xsltproc-nonet.patch: this is really not the right
  fix. It just appears that gnome-doc-utils is lacking a dependency
  on docbook_4.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Fix up use of GcrCertificate
  + Use pool.sks-keyservers.net instead of pgp.mit.edu
  + Build fixes.
  + Updated translations.
- Rebase seahorse-xsltproc-nonet.patch.
- Replace libgp11-devel BuildRequires with libgck-devel: gp11
  library has been removed from gnome-keyring since version 2.91.2,
  but was replaced with libgck.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Now builds with GTK+ 3.x by default.
  + Fix build issues on GTK+ 3.x.
  + Fix problem importing SSH keys.
  + Updated translations.
* Thu Apr  7 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Set the primary-toolbar style class on the toolbar
- Changes from version 2.91.92:
  + About dialog is transient for main window.
  + When changing a PGP key's passpharse, ask for confirmation.
  + Fix crash in SSH key parsing.
  + Update icons
  + Build fixes
- Changes from version 2.91.91:
  + Fix infinite loop when a keyring item is open.
  + Don't display underlines as keys for a PGP uid.
  + Escape keyring attribute names properly.
  + Add context to translatable strings.
- Changes from version 2.91.4:
  + Update to work with GTK+3
  + Fix build issues with GCR updates
  + More info when --version is specified
  + Fix setting key trust to "never"
  + Define default key length for each algorithm
  + Show information when you sign an UID twice
- Changes from version 2.91.2
  + Escape markup when displaying keyring item attributes
  + Fixes for new GTK+3 GtkComboText class and libnotify
- Changes from version 2.91.1.1:
  + Fix build with libnotify 0.7
  + Migrate to new GtkComboBoxText widget in GTK3
  + Fix build issues on gtk+-3.0
  + Build with latest gcr
  + Add icons and clear action to the filter entry
  + Avoid hard-coding Gtk+ API version in gir generation
- Changes from version 2.91.1:
  + Migration to GTK+ 3.0
  + Fix compiler warnings.
  + Use new gck library instead of old gp11.
- Changes from version 2.91.0:
  + Move DNS-SD key sharing to separate project
- Pass --with-gtk=3.0 to configure to build against gtk3.
- Add gobject-introspection-devel BuildRequires to build
  introspection support.
- Update descriptions / summaries to stop mentioning GNOME2.
- Fix parameters order in %%suse_update_desktop_file call.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Jan 31 2011 dimstar@opensuse.org
- BuildRequire libassuan-devel. This is not a new dependency, just
  one that happened to be automatically pulled in earlier by
  gpgme-devel.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Make builds silent by default
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + Documentation
  + Use GDK accessor functions
  + Use smaller icons in "new" dialog
  + Build fixes
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Fixes all but one issue for compiling with -DGSEAL_ENABLE
  + Remove deprecated GTK+ symbol
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to 2.30.0:
  + Source documentation.
  + Updated translations.
* Mon Feb 22 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Change default key lengths for subkey generation.
  + Remove unused variables
  + Revoking subkey now works again. Also minor documentation
    changes.
  + Don't show the passphrase in plaintext.
  + Check the OpenPGP engine only
  + Fixed wrong variable names in comments
  + Clean up version constants
  + Fixed two warnings at compile time
  + Unescape URI's before presenting them to the user.
  + Updated year in the copyright string of the about dialog
  + Fixed incorrect signal name
  + Fixed bug in the public key properties GUI.
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + pgp: Make subkey creation more robust
  + Drop daemon autostart file
  + Update eggdesktopfile.[ch] from libegg/smclient
  + Various fixes
  + Updated translations.
- Drop seahorse-missing-sentinel.patch: fixed upstream.
- Do not call suse_update_desktop_file on seahorse-daemon: it got
  removed.
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + Experimental support for introspection of libcryptui
  + Full documentation for seahorse-context.c
  + Do not use fixed MAXPATHLEN size buffers for portability
  + Add seahorse man page
  + Fix build with latest gp11
  + Updated translations.
- Add seahorse-missing-sentinel.patch to fix build.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
- Add libgcr-devel and libgp11-devel BuildRequires, that used to
  live with gnome-keyring-devel.
- Pass --disable-schemas-install to configure.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Set default key length to 2048 bits
  + Generate RSA-sign/RSA-encrypt key in one pass
  + Support GPG 2.0
  + Fix window signals
  + GTK-doc comments
  + SSH Key importing fix
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + None
- Changes from version 2.28.1:
  + Prevent opening help window twice.
  + Set bits setting properly when creating SSH key.
  + Add support for GnuPG DSA2 keys.
  + Fix subkey creation on newer GnuPG versions
  + Fix location label in SSH key properties.
  + Fix assertion on exit.
  + Fix pasting into filter field.
  + Set key usage flags properly.
  + Fix property bindings.
  + Internal documentation.
  + Translation fixes.
  + Build fixes.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + void function should not return a value.
* Mon Sep 14 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Include config.h to avoid build breakage when gpgme is compiled
    with LFS
  + Fix problems with gtk-builder UI files.
  + Fix problem with 'Type:' label of SSH key displaying location.
  + Update context menu display after keyring op.
  + Fix more compiler warnings.
  + Optionally use silent automake build rules.
  + Clean up old libglade and CVS files.
  + Respect the button-images setting, and cleanup gtkbuilder xml.
  + Add keyring docs.
  + Lots of documentation work.
- Do not change CFLAGS: should not be needed anymore.
* Mon Aug 10 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Fix problem with missing password tab.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Fix logic for setting owner trust combo.
  + More Code and API documentation.
  + Old result in search dialog is selected.
  + seahorse-daemon should autostart by default
  + Add a --version parameter to seahorse.
  + No longer daemonizes when autostarted by D-Bus.
  + Gray out displayed non-trusted keys.
  + Remove the 'trusted keys' tab and combine with 'other keys'.
  + Use GtkBuilder instead of libglade.
  + Add support for adding manual keyring secrets.
  + Move password tab to first place.
  + Remove unportable test(1) construct in configure script.
- Remove libglade2-devel BuildRequires.
* Mon Jul 13 2009 coolo@novell.com
- compile with large file support
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Distribute earlier ChangeLogs
  + Fix importing context menus in search dialogs
  + Updated translations.
- Also package ChangeLog.pre-auto.
* Sun Apr 12 2009 mboman@suse.de
- Update to version 2.26.1:
  + PGP UIDs display in order reported by key server, and fix
    parsing of HKP PGP search UIDs
  + Fix problem opening preferences window twice
  + Set authorized_keys properly when sending SSH keys to a remote
    system
  + Fix crash when entering hkp: url manually
- Don't package omf files in main package since they are in -lang
* Sat Mar 14 2009 mboman@suse.de
- Update to version 2.26.0:
  + Fix cancel button in 'Add keyring' dialog
  + Update GUI before showing window, to avoid GUI changes
    when selection is initialized
  + Allow multiple "Sync and Publish" windows to open
  + Disable input method in password prompt
  + Fix various crashers, and smaller bugs
* Mon Mar  2 2009 mboman@suse.de
- Update to version 2.25.92:
  + Fix crash when typing in a custom key server URL
  + Searching by key identifiers now shows results
  + Don't crash when loading a PGP key that loads the secret
    part before the public part
  + Disable interactive tree search in key manager
  + Fix issues with object IDs, crashes and other inconsistencies
    when accessed via DBus
  + Add libcryptui documentation
  + Reference counting fixes
  + Remove use of GTK+ deprecated symbols
  + Use proper GTK+ stock item names
  + Collapse 'Advanced Options' in PGP key generate dialog
    by default
  + Translation updates
- Remove BuildRequires gcc-c++
- Remove %%{release} from Requires
- Remove gconf2-devel from Requires
- Remove 'CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing
  - DLDAP_DEPRECATED -DWITH_SSH"'
- Don't use %%{?suse_update_config:%%{suse_update_config -f}}
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Feb 14 2009 mboman@suse.de
- Update to version 2.25.91:
  + Display keyring creation dialog properly
  + Prompt before deleting a keyring
  + Refresh after adding a keyring
  + Translation and doc fixes
  + Build PKCS#11 support properly
  + 64-bit fixes
  + Only autostart seahorse-daemon when key sharing is
    enabled
  + seahorse-daemon no longer times out login of
    session
  + Fix libcryptui regressions
  + Remove explicit line breaks from glade files
  + Build fixes
- Use --disable-scrollkeeper with configure
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.25.90:
  + Removed libtasn1 dependency
  + Additional refactoring
  + seahorse-daemon registers with session manager properly
  + gtk-doc for libcryptui
  + Remove bits of libcryptui that are now handled by the gcr
    library
    from gnome-keyring
  + Translation updates
* Wed Jan 28 2009 vuntz@novell.com
- Own /usr/share/gnome/help to not depend on libgnome.
* Fri Jan 23 2009 vuntz@novell.com
- Clean up file list, and move the autostart desktop file to
  /etc/xdg/autostart (already done upstream in trunk)
* Thu Jan  8 2009 mboman@suse.de
- Update to version 2.25.4:
  + Fix crash when uploading ssh keys
  + Code update for gp11 library changes
- Remove seahorse-revert-get-slot.patch. Fixed upstream
* Wed Dec 24 2008 mboman@suse.de
- Update to version 2.25.3:
  + Massive refactoring
  + Use g_timeout_add_seconds instead of g_timeout_add
  + Fix display of expiry date time
  + Autostart seahorse-daemon
  + Various fixes
  + Fix connecting to ssh servers not on port 22
  + Translation updates
- Add seahorse-revert-get-slot.patch. Reverts svn submission 2671
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.1:
  + Clean up GLib and GTK+ includes (GNOME Goal)
  + Clean up errors in declaration of signal handlers
  + Translation updates
* Tue Nov  4 2008 vuntz@novell.com
- Update BuildRequires since upstream split the packages with
  seahorse-plugins.
- Move .so to devel package.
* Mon Oct 20 2008 mboman@suse.de
- Update to version 2.24.1:
  + Fix problems with seahorse crashing when searching for
    remote keys.
  + Build fixes on Solaris
  + Fix selection of keys in libcryptui.
  + I18n fixes.
* Tue Oct  7 2008 meissner@suse.de
- removed xulrunner requires (since plugin is gone too)
* Wed Sep 24 2008 maw@suse.de
- Update to version 2.24.0:
  + Some tweaks to the password prompt window, including allowing
    minimizing to release the keyboard grab
  + Return a 'cancelled' error when from the daemon crypto dbus
    methods when a user cancels out of a password prompt
  + Show revoked subkeys properly in details view of PGP keys
  + Fix problem deleting SSH keys
  + Fix dialog prompt column widths, and elipsize long text in
    key listing
  + Fix problem with 'no keys available' when trying to sign a
    PGP key from within the key manager
  + Add 'exportable' flag to objects/keys and don't enable export
    UI if selected objects are not exportable
  + Misc. other fixes.
* Wed Sep 24 2008 wr@opensuse.org
- removed traces of unused subpackages (part of bnc#420641)
- added libnotify support
- removed obsolete configure options
* Mon Sep  8 2008 mboman@novell.com
- Update to version 2.23.92:
  + Fix crash when changing a stored Gnome Keyring password.
  + Fix certain crashes on syncing, searching and other operations.
  + Fix dumb 'Couldn't import keys' error message when success.
* Thu Sep  4 2008 mboman@novell.com
- Updated to 2.23.91:
  + Fix copying keys to the clipboard.
  + Fix double free crash when importing keys.
  + Fix crasher when deleting a key.
  + Don't add extra null bytes to SSH authorized_keys and
    similar files.
  + Documentation fixes.
  + Don't repeatedly load gnome-keyring items.
  + Make help button in 'First Time Options' work proprely.
  + Better wording for options in PGP key dialogs.
* Sat Aug 30 2008 mboman@novell.com
- Updated to 2.23.90:
  + Icon makeover
* Tue Aug  5 2008 captain.magnus@opensuse.org
- Updated to 2.23.6
  + Initial PKCS#11 certificate listing implementation.
  + Internal code refactoring.
  + Fix problems with reference counting on operations.
  + Use base64 functions in glib, rather than rolling our own.
  + Don't use deprecated LDAP functions. [Adam Schreiber]
  + String operation fixes. [Adam Schreiber]
  + Build fixes [Jeff Cai]
- Removed seahorse-strncat.patch
* Sat Aug  2 2008 captain.magnus@opensuse.org
- Removed seahorse-configure.patch
- Removed seahorse-ephy-2.22.patch (Plugins are gone)
- Removed seahorse-mozilla-xulrunner19.patch (gecko.m4 is no more)
- Updated to 2.23.5
  + Fix importing keys from key servers [Mackenzie Morgan]
  + Factor out seahorse-plugins to a different module.
  + Add XDS drag and drop support.
  + Remove gnome-vfs dependency and use gio instead.
  + Return key id of signer from DBus service even when key
  is not found locally [Adam Schreiber]
  + Refactor UI code internally into modules.
  + Remove hard GPG and GPGME dependency.
  + Replace signer drop down in key chooser with just a check
  button when only one secret key exists. [Adam Schreiber]
  + Set sync button insensitive when no server is selected.
  [Adam Schreiber]
  + Test for secure memory before using it. [Coleman Kane]
  + Change trust model used to match GPG's. [Adam Schreiber]
  + Remove libgnome and libgnomeui dependencies. [Saleem Abdulrasool]
  + Grab keyboard focus when prompting for password.
  [Josselin Mouette]
  + Use the vala programming language for some code.
  + Add initial infrastructure for PKCS#11 key/certificate support.
  + Save and load window sizes from gconf. [Adam Schreiber]
  + Build fixes [Brian Cameron, Saleem Abdulrasool, Alexis Ballier,
  Christian Persch, Rodrigo Moya]
* Fri Jul 18 2008 rodrigo@suse.de
- Tag and upstream patches.
* Mon Jun 30 2008 maw@suse.de
- Remove the .desktop file icon copying hack.
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.22.2:
  + Fix importing keys from hkp keyservers.
* Fri Jun 20 2008 schwab@suse.de
- Fix configure script.
* Tue May 13 2008 maw@suse.de
- Create new subpackages (bnc#387472):
  + -gedit-plugin
  + -epiphany-plugin, which needs seahorse-ephy-2.22.patch.
* Wed May  7 2008 hpj@suse.de
- Require gnome-panel-devel for building, so panel applet gets
  installed.
- Add a category to one of the desktop files, so the keyring/encryption
  preferences applet appears in the control center.
* Fri Apr 11 2008 maw@suse.de
- Update to version 2.22.1:
  + Remove code related to secure memory that was made unnecessary
    due to its functionality being provided by gnome-keyring.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Cosmetic version bump.
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.92:
  + Documentation updates
  + Translation fixes.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.91:
  + Adapt to new Epiphany API.
* Tue Jan 29 2008 maw@suse.de
- Update to version 2.21.90:
  + Remove options that screw with gpg.conf on seahorse-agent
    startup, since this was unsafe and naive
  + Update libsoup optional dependency to depend on 2.4.x
  + Add icon for the gedit plugin
  + Don't add extra dot to encrypted or compressed files
  + Fix build problems with nautilus 2.21.x and later
  + Install nautilus extension to correct directory
  + Support better dropping of text keys onto main window.
* Wed Jan  9 2008 maw@suse.de
- Update to 2.21.4:
  + Remove ssh proxy since gnome-keyring now has a proper ssh agent
  + Don't hardcode epiphany extensions directories
  + Improved gnome-keyring integration
  + UI and HIG improvements
  + Disable automatic key uploading/retrieval by default
  + Minor fixes
- Remove seahorse-desktop.patch because it has been upstreamed
- Actually remove seahorse-gpgme-version.patch
- Add seahorse-strncat.patch and seahorse-xsltproc-nonet.patch.
* Fri Dec 14 2007 jpr@suse.de
- Update to 2.20.1
  * Fix selection of archive names when encrypting.
  * Now works with Gedit 2.20
  * Other UI and code fixes
- Remove upstreamed patch seahourse-abuild-warnings.patch
- Annotate seahourse-desktop.patch
* Wed Dec  5 2007 maw@suse.de
- Don't require openldap2 to build.
* Wed Nov 21 2007 maw@suse.de
- Rename abuild.patch to seahorse-abuild-warnings.patch
- That patch now fixes more questionable code.
* Thu Oct 11 2007 sbrabec@suse.cz
- Use correct binding specific avahi package instead of
  mDNSResponder.
* Wed Sep 19 2007 maw@suse.de
- Respin abuild.patch based on feedback from a seahorse maintainer
  (thanks, Adam)
- Run %%suse_update_desktop_file against more .desktop files.
* Tue Sep 18 2007 maw@suse.de
- Update to version 2.20.0:
  + The large version bump is due to the seahorse project
    synchronizing its version numbers with those of much of the
    rest of the GNOME project
  + Hide the agent tray icon by default
  + Can now change gnome keyring master password
  + Added option to disable auto-retrieval of keys from key
    servers
  + Give more detail for imported keys
  + Display gnome-keyring items properly
  + Progress windows show up in the window list now
  + Wrap text in the encryption applet properly
  + Now builds with GPG 2.0
  + Can now select archive extensions properly when encrypting
    files
  + Fix problem with internationalized expiration dates on PGP
    keys
  + Select a proper key size for SSH DSA keys
  + Allow SSH keys to be uploaded to machines listening on
    non-standard ports
  + Can now import SSH keys that were generated elsewhere
  + Dialog and HIG fixes
  + Fix build problems
  + Fix crashers and problematic assertions
  + Updated translations
- Respin abuild.patch
- Remove seahorse-gpg-version.patch, which has been upstreamed.
* Wed Sep  5 2007 maw@suse.de
- Correct a .desktop file (#272535).
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Fri Jun 22 2007 maw@suse.de
- s/gpg/gpg2/ in the buildreq
- Add seahorse-gpg-version.patch to allow builds when only gpg2
  is installed.
* Tue Jun  5 2007 ro@suse.de
- added gpg to buildreq
* Mon Apr 16 2007 maw@suse.de
- Create a -devel subpackage (#262572).
* Wed Apr 11 2007 maw@suse.de
- Update to version 1.0.1
- Many fixes:
  * Fix a crash when deleting keys.
  * Require GTK+ 2.10 without which 1.0 didn't build
  * Use /tmp directory for agent sockets, so that seahorse
    works for people with home directories on NFS/AFS
  * Fixed importing of private keys from ssh-keygen
  * Fixed checks for memory locking
  * Epiphany plugin now builds with Epiphany 2.18 [Adam Schreiber]
  * Set a default icon for all seahorse windows.
  * Now able to use ports other than 22 when sending an SSH
    key to another computer.
  * Internationalization fixes [Bjoern Voigt]
  * Handle openssh's authorized_keys file more cleanly
  * Handle spaces in a search text when searching an LDAP server
  * Help now works in 'Search Results' window [Adam Schreiber]
  * Other minor fixes
- Updated translations for the ar, bg, ca, da, dz, el, es, et, fi,
  fr, it, gu, ja, lt, mk, nb, pt, pt_BR, sv, and th locales.
* Tue Apr 10 2007 maw@suse.de
- Add abuild.patch, to silence some warnings.
* Tue Apr 10 2007 maw@suse.de
- Add openssh as an additional build requirement.
* Mon Apr  9 2007 maw@suse.de
- Update to version 1.0
- Remove seahorse-uninited.patch which no longer appears to apply
- Many fixes for bugzilla.gnome.org incl. #415808, #408774, #414078,
  [#411834], #408786, #410193, #408774, #406337, #408335, #375062,
  [#404386], #402856, #391666, #396009, #393218, #393366, #391699,
  [#391700], #363350, #387402, #357323, #349286, #336146, #354432,
  [#388318], #338730, #387293, #376729, #384781, #324674, #354245,
  [#358697], #362711, #382330, #374257, #377938, #376098, #376707,
  [#376098], #369536, #369616, #371636, #371666, #372099, #369874,
  [#363282], #351969, #368748, #366749, #355378, #364081, #361897,
  [#356794], #355380, #356302, #357317, #356550, #355386, #355378,
  [#355833], #355420, #355305, #353494, #354332, #354251, #354245,
  [#351935], #353595, #352808, #351836, #352868, #352364, #352332,
  [#345990], #352087, #351862, #351862, #351874, #351980, #351859,
  [#351850], #351833, #350206, #338287, #347872, #156306, #347869,
  [#349080], #348770, #347868, #339237, #339237, #341987, #347459,
  [#346418], #346038, #346040, #341986, #341986, #341986, #338743,
  and #342005
- No longer try to rename certain localizations
- Buildrequire gnome-doc-utils-devel
* Sun Apr  1 2007 ro@suse.de
- updated gconf scriptlets
* Mon Feb  5 2007 ro@suse.de
- GNOME moved to /usr
* Thu Dec  7 2006 sbrabec@suse.cz
- Fixed MIME database path in scriptlets (#225666).
- Use correct PreReq.
- Do not touch obsolete run-scrollkeeper-update.
* Mon Dec  4 2006 jhargadon@suse.de
- removed ownership of /opt/gnome/share/mime (#225667)
* Sun Sep  3 2006 ro@suse.de
- fix build (find icon file)
* Tue Jul 18 2006 nadvornik@suse.cz
- fixed check for minimal gpgme version
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gpgme-devel to nfb
* Fri Jan  6 2006 gekker@suse.de
- Initial import into autobuild, version 0.8 (#131375)
